Bibliography
============

Bibliography
------------

.. [Egerton2011] Ray Egerton, "Electron Energy-Loss Spectroscopy in the
   Electron Microscope", Springer-Verlag, 2011.

.. _articles-about-hyperspy:

.. _articles-using-hyperspy:

Peer-review articles with results obtained using HyperSpy
---------------------------------------------------------

.. note::

   Given the incresing number of articles that cite HyperSpy we no longer
   update the list of articles below. For an up to date list search for
   HyperSpy in a scientific database e.g. `Google Scholar
   <https://scholar.google.co.uk/scholar?hl=en&q=hyperspy&btnG=&as_sdt=1%2C5>`_.

.. Warning::
    The articles published before 2012 may mention the HyperSpy project under 
    its old name, EELSLab
    
.. raw:: html
    :file: ../_static/articles_using_hyperspy.html
